#!/usr/bin/env python

"""
Add users to a MoinMoin wiki, fetching the profile of each user from a
Confluence site in order to obtain name and e-mail details.

User details are written to standard output in a tab-separated sequence using
the following format:

USERNAME FULLNAME EMAIL IMAGE-URL PASSWORD
"""

from time import sleep
from os.path import split
from subprocess import call
import random, string
import sys

this_dir = split(sys.argv[0])[0]
sys.path.append(this_dir)

from get_profile import get_profile

def randompass():
    return "".join(random.sample(string.ascii_letters, 10))

def add_user(wiki, username, fullname, email, password):
    cmd = ["moin", "--config-dir=%s" % wiki, "account", "create",
        "--name=%s" % username,
        "--email=%s" % email,
        "--password=%s" % password] + \
        (fullname and ["--alias=%s" % fullname] or [])
    call(cmd)

def main():
    progname = split(sys.argv[0])[-1]

    try:
        wiki = sys.argv[1]
        url = sys.argv[2]
        delay = int((sys.argv[3:4] or ["1"])[0])
    except (IndexError, ValueError):
        print >>sys.stderr, "%s <wiki configuration directory> <wiki URL> [ <retrieval delay> ]" % progname
        print >>sys.stderr
        print >>sys.stderr, "Example: %s wiki http://wiki.list.org/" % progname
        sys.exit(1)

    line = sys.stdin.readline()
    while line:
        username = line.strip()
        username, fullname, email, image = get_profile(url, username)
        password = randompass()
        add_user(wiki, username, fullname, email, password)
        print "\t".join([username, fullname, email, image, password])

        sleep(delay)
        line = sys.stdin.readline()

if __name__ == "__main__":
    main()

# vim: tabstop=4 expandtab shiftwidth=4
